package org.fax4j.spi.http;

import java.util.Properties;

/**
 * Holds the HTTP request data used to send the fax data to the
 * web server.
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.01
 * @since	0.1
 */
public class HTTPRequest extends AbstractHTTPPayload
{
	/**The requested resource*/
	private String resource;
	/**The URL parameters text*/
	private String parametersText;
	/**The header properties*/
	private Properties headerProperties;

	/**
	 * This is the default constructor.
	 */
	public HTTPRequest()
	{
		super();
	}

	/**
	 * This function returns the requested resource.
	 * 
	 * @return 	The requested resource
	 */
	public String getResource()
	{
		return this.resource;
	}

	/**
	 * This function returns the URL parameters text.
	 * 
	 * @return 	The URL parameters text
	 */
	public String getParametersText()
	{
		return this.parametersText;
	}

	/**
	 * This function returns the header properties.
	 * 
	 * @return 	The header properties
	 */
	public Properties getHeaderProperties()
	{
		return this.headerProperties;
	}

	/**
	 * This function sets the requested resource.
	 * 
	 * @param 	resource
	 * 			The new value for the requested resource
	 */
	public void setResource(String resource)
	{
		this.resource=resource;
	}

	/**
	 * This function sets the URL parameters text.
	 * 
	 * @param 	parametersText
	 * 			The new value for the URL parameters text
	 */
	public void setParametersText(String parametersText)
	{
		this.parametersText=parametersText;
	}

	/**
	 * This function sets the header properties.
	 * 
	 * @param 	headerProperties
	 * 			The new value for the header properties
	 */
	public void setHeaderProperties(Properties headerProperties)
	{
		this.headerProperties=headerProperties;
	}
}